return {
  fields = {
    box_error = {
      fields = {
        [")"] = {
          detail = "Throw an error",
          type = "function"
        },
        ["box.error"] = {
          description = "\n===============================================================================\n                                   Overview\n===============================================================================\n\nThe ``box.error`` function is for raising an error. The difference between this\nfunction and Lua's built-in `error <https://www.lua.org/pil/8.3.html>`_ function\nis that when the error reaches the client, its error code is preserved.\nIn contrast, a Lua error would always be presented to the client as\n``ER_PROC_LUA``.\n\n===============================================================================\n                                    Index\n===============================================================================\n\nBelow is a list of all ``box.error`` functions.\n\n.. container:: table\n\n    .. rst-class:: left-align-column-1\n    .. rst-class:: left-align-column-2\n\n    +--------------------------------------+---------------------------------+\n    | Name                                 | Use                             |\n    +======================================+=================================+\n    | `box.error()                    | Throw an error                  |\n    |`                   |                                 |\n    +--------------------------------------+---------------------------------+\n    | `box.error.last()               | Get a description of the        |\n    |`                    | last error                      |\n    +--------------------------------------+---------------------------------+\n    | `box.error.clear()              | Clear the record of errors      |\n    |`                   |                                 |\n    +--------------------------------------+---------------------------------+\n    | `box.error.new()                | Create an error but do not      |\n    |`                     | throw                           |\n    +--------------------------------------+---------------------------------+\n\n``box.error`` throws an object that has the cdata type and contain the following\nfields:\n\n* \"type\" (string) error's C++ class,\n* \"code\" (number) error's number,\n* \"message\" (string) error's message,\n* \"file\" (string) Tarantool source file,\n* \"line\" (number) line number in the Tarantool source file,\n* \"errno\" (number) C standard error number; this field is added only if the error\n  is a system error (for example, due to a failure in a socket or file i/o).\n\n",
          type = "module"
        },
        ["box.error.clear"] = {
          argsDisplay = "",
          description = "Clear the record of errors, so functions like ``box.error()``\n    or ``box.error.last()`` will have no effect.\n\n    **Example:**\n\n    ```lua\n        tarantool> box.schema.space.create('')\n        ---\n        - error: Invalid identifier '' (expected printable symbols only or it is too long)\n        ...\n        tarantool> box.error.last()\n        ---\n        - Invalid identifier '' (expected printable symbols only or it is too long)\n        ...\n        tarantool> box.error.clear()\n        ---\n        ...\n        tarantool> box.error.last()\n        ---\n        - null\n        ...\n```\n\n.. _box_error-new:\n\n.",
          type = "function"
        },
        ["box.error.last"] = {
          argsDisplay = "",
          description = "Show the last error object.\n\n    **Example**\n\n    You can reach the last error object's fields like this:\n\n    .. code-block:: tarantoolsession\n\n        tarantool> box.schema.space.create('')\n        ---\n        - error: Invalid identifier '' (expected printable symbols only or it is too long)\n        ...\n        tarantool> box.error.last()\n        ---\n        - Invalid identifier '' (expected printable symbols only or it is too long)\n        ...\n        tarantool> box.error.last().code\n        ---\n        - 70\n        ...\n        tarantool> box.error.last().type\n        ---\n        - ClientError\n        ...",
          type = "function"
        },
        ["box.error.new"] = {
          argsDisplay = "code, errtext [, errtext ...]",
          description = "Create an error object, but do not throw.\n    This is useful when error information should be saved for later retrieval.\n    The parameters are the same as for `box.error()`,\n    see the description there.",
          type = "function"
        },
        clear = {
          detail = "Clear the record of errors",
          type = "function"
        },
        last = {
          detail = "Get a description of the last error",
          type = "function"
        },
        new = {
          detail = "Create an error but do not throw",
          type = "function"
        }
      },
      type = "table"
    }
  },
  type = "table"
}