return {
  fields = {
    box_snapshot = {
      fields = {
        ["box.snapshot"] = {
          argsDisplay = "",
          description = "Take a snapshot of all data and store it in\n    `memtx_dir`:samp:`/{<latest-lsn>}.snap`.\n    To take a snapshot, Tarantool first enters the delayed garbage collection\n    mode for all data. In this mode, the\n    `Tarantool garbage collector` will not\n    remove files which were created before the snapshot started, it will not\n    remove them until the snapshot has finished. To\n    preserve consistency of the primary key, used to iterate over tuples, a\n    copy-on-write technique is employed. If the master process changes part\n    of a primary key, the corresponding process page is split, and the snapshot\n    process obtains an old copy of the page.\n    In effect, the snapshot process uses multi-version concurrency control\n    in order to avoid copying changes which are superseded while it is running.\n\n    Since a snapshot is written sequentially, one can expect a very high write\n    performance (averaging to 80MB/second on modern disks), which means an average\n    database instance gets saved in a matter of minutes.\n    Users may restrict the speed by changing\n    `snap_io_rate_limit`.\n    \n    .. NOTE::\n    \n       As long as there are any changes to the parent index memory through\n       concurrent updates, there are going to be page splits, and therefore you\n       need to have some extra free memory to run this command. 10% of\n       `memtx_memory` is, on average, sufficient.\n       This statement waits until a snapshot is taken and returns operation result.\n\n    .. NOTE::\n    \n       **Change notice:** Prior to Tarantool version 1.6.6, the snapshot process\n       caused a fork, which could cause occasional latency spikes. Starting with\n       Tarantool version 1.6.6, the snapshot process creates a consistent\n       read view and this view is written to the snapshot file by a separate thread\n       (the \"Write Ahead Log\" thread).\n\n       Although ``box.snapshot()`` does not cause a fork, there is a separate fiber\n       which may produce snapshots at regular intervals -- see the discussion of\n       the `checkpoint daemon`.\n\n    **Example:**\n\n    ```lua\n        tarantool> box.info.version\n        ---\n        - 1.7.0-1216-g73f7154\n        ...\n        tarantool> box.snapshot()\n        ---\n        - ok\n        ...\n        tarantool> box.snapshot()\n        ---\n        - error: can't save snapshot, errno 17 (File exists)\n        ...\n```\n\n    Taking a snapshot does not cause the server to start a new write-ahead log.\n    Once a snapshot is taken, old WALs can be deleted as long as all replicated\n    data is up to date. But the WAL which was current at the time ``box.snapshot()``\n    started must be kept for recovery, since it still contains log records\n    written after the start of ``box.snapshot()``.\n\n    An alternative way to save a snapshot is to send a SIGUSR1 signal to the instance.\n    While this approach could be handy, it is not recommended for use\n    in automation: a signal provides no way to find out whether the snapshot\n    was taken successfully or not.",
          type = "function"
        }
      },
      type = "table"
    }
  },
  type = "table"
}