return {
  fields = {
    buffer = {
      fields = {
        buffer = {
          description = "\n",
          type = "module"
        },
        ibuf = {
          argsDisplay = "",
          description = ":return: a descriptor of a buffer.\n    :rtype: cdata\n\n    **Example:**\n\n    Assume a Tarantool server is listening on farhost:3301.\n    Assume it has a space ``T`` with one tuple: ``'ABCDE', 12345``.\n    In this example we start up a server on localhost:3302\n    and then use ``net.box`` routines to connect to farhost.\n    Then we create a buffer, and use it as an option\n    for a ``conn.space...select()`` call.\n    The result will be in MsgPack_ format.\n    To show this, we will use\n    `msgpack.decode_unchecked()`\n    on ``ibuf.rpos`` (the \"read position\" of the buffer).\n    Thus we do not decode on the remote server, but we do\n    decode on the local server.\n\n    ```lua\n        box.cfg{listen=3302}\n        buffer = require('buffer')\n        ibuf = buffer.ibuf()\n        net_box = require('net.box')\n        conn = net_box.connect('farhost:3301')\n        buffer = require('buffer')\n        conn.space.T:select({},{buffer=ibuf})\n        msgpack = require('msgpack')\n        msgpack.decode_unchecked(ibuf.rpos)\n```\n\n    The result of the final request looks like this:\n\n    ```lua\n        tarantool> msgpack.decode_unchecked(ibuf.rpos)\n        ---\n        - {48: [['ABCDE', 12345]]}\n        - 'cdata<char *>: 0x7f97ba10c041'\n        ...\n```\n\n    .. NOTE::\n\n        Before Tarantool version 1.7.7, the function to use for\n        this case is ``msgpack.ibuf_decode(ibuf.rpos)``. Starting\n        with Tarantool version 1.7.7, ``ibuf_decode`` is deprecated.\n\n.. _MsgPack: http://msgpack.org/",
          type = "function"
        }
      },
      type = "table"
    }
  },
  type = "table"
}