return {
  fields = {
    crypto = {
      fields = {
        [""] = {
          detail = "Get a hash key",
          type = "function"
        },
        ["crypto.cipher"] = {
          description = "\n===============================================================================\n                                   Overview\n===============================================================================\n\n\"Crypto\" is short for \"Cryptography\", which generally refers to the production\nof a digest value from a function (usually a `Cryptographic hash function`_),\napplied against a string. Tarantool's ``crypto`` module supports ten types of\ncryptographic hash functions (AES_, DES_, DSS_, MD4_, MD5_, MDC2_, RIPEMD_,\nSHA-1_, SHA-2_). Some of the crypto functionality is also present in the\n`digest` module.\n\n===============================================================================\n                                    Index\n===============================================================================\n\nBelow is a list of all ``crypto`` functions.\n\n.. container:: table\n\n    .. rst-class:: left-align-column-1\n    .. rst-class:: left-align-column-2\n\n    +----------------------------------------------------------+---------------------------------+\n    | Name                                                     | Use                             |\n    +==========================================================+=================================+\n    | :ref:`crypto.cipher.{algorithm}.{cipher_mode}.encrypt()  | Encrypt a string                |\n    |`                                         |                                 |\n    +----------------------------------------------------------+---------------------------------+\n    | `crypto.cipher.{algorithm}.{cipher_mode}.decrypt()  | Decrypt a string                |\n    |`                                         |                                 |\n    +----------------------------------------------------------+---------------------------------+\n    | `crypto.digest.{algorithm}()                        | Get a digest                    |\n    |`                                         |                                 |\n    +----------------------------------------------------------+---------------------------------+\n    | `crypto.hmac.{algorithm}()                          | Get a hash key                  |\n    |`                                           |                                 |\n    +----------------------------------------------------------+---------------------------------+\n\n.. _crypto-cipher:\n\n.. varfunc:: {aes128|aes192|aes256|des}.{cbc|cfb|ecb|ofb}.encrypt(string, key, initialization_vector)\n             {aes128|aes192|aes256|des}.{cbc|cfb|ecb|ofb}.decrypt(string, key, initialization_vector)\n    :needs_modname: True\n\n    Pass or return a cipher derived from the string, key, and (optionally,\n    sometimes) initialization vector. The four choices of algorithms:\n\n    * aes128 - aes-128 (with 192-bit binary strings using AES)\n    * aes192 - aes-192 (with 192-bit binary strings using AES)\n    * aes256 - aes-256 (with 256-bit binary strings using AES)\n    * des    - des (with 56-bit binary strings using DES, though DES is not\n      recommended)\n\n    Four choices of block cipher modes are also available:\n\n    * cbc - Cipher Block Chaining\n    * cfb - Cipher Feedback\n    * ecb - Electronic Codebook\n    * ofb - Output Feedback\n\n    For more information, read the article about `Encryption Modes`_\n\n    **Example:**\n\n    ```lua\n        _16byte_iv='1234567890123456'\n        _16byte_pass='1234567890123456'\n        e=crypto.cipher.aes128.cbc.encrypt('string', _16byte_pass, _16byte_iv)\n        crypto.cipher.aes128.cbc.decrypt(e,  _16byte_pass, _16byte_iv)\n```\n\n",
          type = "module"
        },
        ["crypto.cipher."] = {
          detail = "Decrypt a string",
          type = "function"
        },
        ["crypto.digest"] = {
          description = "\n.. _crypto-digest:\n\n.. varfunc:: {dss|dss1|md4|md5|mdc2|ripemd160}(string)\n             {sha1|sha224|sha256|sha384|sha512}(string)\n    :needs_modname: True\n\n    Pass or return a digest derived from the string. The eleven\n    algorithm choices:\n\n    * dss - dss (using DSS)\n    * dss1 - dss (using DSS-1)\n    * md4 - md4 (with 128-bit binary strings using MD4)\n    * md5 - md5 (with 128-bit binary strings using MD5)\n    * mdc2 - mdc2 (using MDC2)\n    * ripemd160 - ripemd (with 160-bit binary strings using RIPEMD-160)\n    * sha1 - sha-1 (with 160-bit binary strings using SHA-1)\n    * sha224 - sha-224 (with 224-bit binary strings using SHA-2)\n    * sha256 - sha-256 (with 256-bit binary strings using SHA-2)\n    * sha384 - sha-384 (with 384-bit binary strings using SHA-2)\n    * sha512 - sha-512(with 512-bit binary strings using SHA-2).\n\n    **Example:**\n\n    ```lua\n        crypto.digest.md4('string')\n        crypto.digest.sha512('string')\n```\n\n",
          type = "module"
        },
        ["crypto.digest."] = {
          detail = "Get a digest",
          type = "function"
        },
        ["crypto.hmac"] = {
          description = "\n.. _crypto-hmac:\n\n.. varfunc:: {md4|md5|ripemd160}(key, string)\n             {sha1|sha224|sha256|sha384|sha512}(key, string)\n    :needs_modname: True\n\n    Pass a key and a string. The result is an\n    `HMAC <https://en.wikipedia.org/wiki/HMAC>`_\n    message authentication code. The eight\n    algorithm choices:\n\n    * md4 or md4_hex - md4 (with 128-bit binary strings using MD4)\n    * md5 or md5_hex - md5 (with 128-bit binary strings using MD5)\n    * ripemd160 or ripemd160_hex - ripemd (with 160-bit binary strings using RIPEMD-160)\n    * sha1 or sha1_hex - sha-1 (with 160-bit binary strings using SHA-1)\n    * sha224 or sha224_hex - sha-224 (with 224-bit binary strings using SHA-2)\n    * sha256 or sha256_hex - sha-256 (with 256-bit binary strings using SHA-2)\n    * sha384 or sha384_hex - sha-384 (with 384-bit binary strings using SHA-2)\n    * sha512 or sha512_hex - sha-512(with 512-bit binary strings using SHA-2).\n\n    **Example:**\n\n    ```lua\n        crypto.hmac.md4('key', 'string')\n        crypto.hmac.md4_hex('key', 'string')\n```\n\n========================================\nIncremental methods in the crypto module\n========================================\n\nSuppose that a digest is done for a string 'A', then a new part 'B' is appended\nto the string, then a new digest is required. The new digest could be recomputed\nfor the whole string 'AB', but it is faster to take what was computed before for\n'A' and apply changes based on the new part 'B'. This is called multi-step or\n\"incremental\" digesting, which Tarantool supports for all crypto functions.\n\n```lua\n      crypto = require('crypto')\n```\n\n      -- print aes-192 digest of 'AB', with one step, then incrementally\n      key = 'key/key/key/key/key/key/'\n      iv =  'iviviviviviviviv'\n      print(crypto.cipher.aes192.cbc.encrypt('AB', key, iv))\n      c = crypto.cipher.aes192.cbc.encrypt.new(key)\n      c:init(nil, iv)\n      c:update('A')\n      c:update('B')\n      print(c:result())\n      c:free()\n\n      -- print sha-256 digest of 'AB', with one step, then incrementally\n      print(crypto.digest.sha256('AB'))\n      c = crypto.digest.sha256.new()\n      c:init()\n      c:update('A')\n      c:update('B')\n      print(c:result())\n      c:free()\n\n=======================================================\nGetting the same results from digest and crypto modules\n=======================================================\n\nThe following functions are equivalent. For example, the ``digest`` function and\nthe ``crypto`` function will both produce the same result.\n\n```lua\n    crypto.cipher.aes256.cbc.encrypt('x',b32,b16)==digest.aes256cbc.encrypt('x',b32,b16)\n    crypto.digest.md4('string') == digest.md4('string')\n    crypto.digest.md5('string') == digest.md5('string')\n    crypto.digest.sha1('string') == digest.sha1('string')\n    crypto.digest.sha224('string') == digest.sha224('string')\n    crypto.digest.sha256('string') == digest.sha256('string')\n    crypto.digest.sha384('string') == digest.sha384('string')\n    crypto.digest.sha512('string') == digest.sha512('string')\n```\n\n.. _AES: https://en.wikipedia.org/wiki/Advanced_Encryption_Standard\n.. _DES: https://en.wikipedia.org/wiki/Data_Encryption_Standard\n.. _DSS: https://en.wikipedia.org/wiki/Payment_Card_Industry_Data_Security_Standard\n.. _SHA-1: https://en.wikipedia.org/wiki/Sha-1\n.. _SHA-2: https://en.wikipedia.org/wiki/Sha-2\n.. _MD4: https://en.wikipedia.org/wiki/Md4\n.. _MD5: https://en.wikipedia.org/wiki/Md5\n.. _MDC2: https://en.wikipedia.org/wiki/MDC-2\n.. _RIPEMD: http://homes.esat.kuleuven.be/~bosselae/ripemd160.html\n.. _Cryptographic hash function: https://en.wikipedia.org/wiki/Cryptographic_hash_function\n.. _Consistent Hashing: https://en.wikipedia.org/wiki/Consistent_hashing\n.. _Encryption Modes: https://en.wikipedia.org/wiki/Block_cipher_mode_of_operation",
          type = "module"
        }
      },
      type = "table"
    }
  },
  type = "table"
}