return {
  fields = {
    debug_facilities = {
      fields = {
        debug = {
          description = "\nThe ``debug`` library provides an interface for debugging Lua programs. All\nfunctions in this library reside in the ``debug`` table. Those functions that\noperate on a thread have an optional first parameter that specifies the thread\nto operate on. The default is always the current thread.\n\n.. NOTE::\n\n    This library should be used only for debugging and profiling and not as a\n    regular programming tool, as the functions provided here can take too long\n    to run. Besides, several of these functions can compromise otherwise\n    secure code.\n\n===============================================================================\n                                    Index\n===============================================================================\n\nBelow is a list of all ``debug`` functions.\n\n.. container:: table\n\n    .. rst-class:: left-align-column-1\n    .. rst-class:: left-align-column-2\n\n    +--------------------------------------+---------------------------------+\n    | Name                                 | Use                             |\n    +======================================+=================================+\n    | `debug.debug()                  | Enter an interactive mode       |\n    |`                       |                                 |\n    +--------------------------------------+---------------------------------+\n    | `debug.getfenv()                | Get an object's environment     |\n    |`                     |                                 |\n    +--------------------------------------+---------------------------------+\n    | `debug.gethook()                | Get a thread's current hook     |\n    |`                     | settings                        |\n    +--------------------------------------+---------------------------------+\n    | `debug.getinfo()                | Get information about a         |\n    |`                     | function                        |\n    +--------------------------------------+---------------------------------+\n    | `debug.getlocal()               | Get a local variable's name and |\n    |`                    | value                           |\n    +--------------------------------------+---------------------------------+\n    | `debug.getmetatable()           | Get an object's metatable       |\n    |`                |                                 |\n    +--------------------------------------+---------------------------------+\n    | `debug.getregistry()            | Get the registry table          |\n    |`                 |                                 |\n    +--------------------------------------+---------------------------------+\n    | `debug.getupvalue()             | Get an upvalue's name and value |\n    |`                  |                                 |\n    +--------------------------------------+---------------------------------+\n    | `debug.setfenv()                | Set an object's environment     |\n    |`                     |                                 |\n    +--------------------------------------+---------------------------------+\n    | `debug.sethook()                | Set a given function as a hook  |\n    |`                     |                                 |\n    +--------------------------------------+---------------------------------+\n    | `debug.setlocal()               | Assign a value to a local       |\n    |`                    | variable                        |\n    +--------------------------------------+---------------------------------+\n    | `debug.setmetatable()           | Set an object's metatable       |\n    |`                |                                 |\n    +--------------------------------------+---------------------------------+\n    | `debug.setupvalue()             | Assign a value to an upvalue    |\n    |`                  |                                 |\n    +--------------------------------------+---------------------------------+\n    | `debug.traceback()              | Get a traceback of the call     |\n    |`                   | stack                           |\n    +--------------------------------------+---------------------------------+\n\n.. _debug-debug:\n\n",
          detail = "Enter an interactive mode",
          type = "module"
        },
        getfenv = {
          argsDisplay = "object",
          description = ":param object: object to get the environment of\n    :type object: table, userdata, thread or function",
          detail = "Get an object's environment",
          type = "function"
        },
        gethook = {
          argsDisplay = "[thread]",
          description = ":return: the current hook settings of the ``thread`` as three values:\n\n      * the current hook function\n      * the current hook mask\n      * the current hook count as set by the ``debug.sethook()`` function\n\n.. _debug-getinfo:\n\n.",
          detail = "Get a thread's current hook settings",
          type = "function"
        },
        getinfo = {
          argsDisplay = "[thread,] function [, what]",
          description = ":param function: function to get information on\n    :type function: function or number\n    :param string what: what information on the ``function`` to return",
          detail = "Get information about a function",
          type = "function"
        },
        getlocal = {
          argsDisplay = "[thread,] level, local",
          description = ":param number level: level of the stack\n    :param number local: index of the local variable",
          detail = "Get a local variable's name and value",
          type = "function"
        },
        getmetatable = {
          argsDisplay = "object",
          description = ":param object: object to get the metatable of\n    :type object: table, userdata, thread or function",
          detail = "Get an object's metatable",
          type = "function"
        },
        getregistry = {
          argsDisplay = "",
          description = ":return: the registry table\n\n.. _debug-getupvalue:\n\n.",
          detail = "Get the registry table",
          type = "function"
        },
        getupvalue = {
          argsDisplay = "func, up",
          description = ":param function func: function to get the upvalue of\n    :param number up: index of the function upvalue",
          detail = "Get an upvalue's name and value",
          type = "function"
        },
        setfenv = {
          argsDisplay = "object, table",
          description = "Sets the environment of the ``object`` to the ``table``.\n\n    :param object: object to change the environment of\n    :type object: table, userdata, thread or function\n    :param table table: table to set the object environment to",
          detail = "Set an object's environment",
          type = "function"
        },
        sethook = {
          argsDisplay = "[thread,] hook, mask [, count]",
          description = "Sets the given function as a hook.  When called without arguments,\n    turns the hook off.\n\n    :param function hook: function to set as a hook\n    :param string mask: describes when the ``hook`` will be called;\n      may have the following values:\n\n      * ``c`` - the ``hook`` is called every time Lua calls a function\n      * ``r`` - the ``hook`` is called every time Lua returns from a function\n      * ``l`` - the ``hook`` is called every time Lua enters a new line of code",
          detail = "Set a given function as a hook",
          type = "function"
        },
        setlocal = {
          argsDisplay = "[thread,] level, local, value",
          description = "Assigns the value ``value`` to the local variable with the index ``local``\n    of the function at level ``level`` of the stack.\n\n    :param number level: level of the stack\n    :param number local: index of the local variable\n    :param value: value to assign to the local variable\n    :type value: boolean, number, string or userdata",
          detail = "Assign a value to a local variable",
          type = "function"
        },
        setmetatable = {
          argsDisplay = "object, table",
          description = "Sets the metatable of the ``object`` to the ``table``.",
          detail = "Set an object's metatable",
          type = "function"
        },
        setupvalue = {
          argsDisplay = "func, up, value",
          description = "Assigns the value ``value`` to the upvalue with the index ``up``\n    of the function ``func``.\n\n    :param function func: function to set the upvalue of\n    :param number up: index of the function upvalue\n    :param value: value to assign to the function upvalue\n    :type value: boolean, number, string or userdata",
          detail = "Assign a value to an upvalue",
          type = "function"
        },
        traceback = {
          argsDisplay = "[thread,] [message] [, level]",
          description = ":param string message: an optional message prepended to the traceback\n    :param number level: specifies at which level to start the traceback\n                         (default is 1)",
          detail = "Get a traceback of the call stack",
          type = "function"
        }
      },
      type = "table"
    }
  },
  type = "table"
}