return {
  fields = {
    digest = {
      fields = {
        ["aes256cbc.decrypt"] = {
          detail = "Decrypt a string using AES",
          type = "function"
        },
        ["aes256cbc.encrypt"] = {
          detail = "Encrypt a string using AES",
          type = "function"
        },
        base64_decode = {
          argsDisplay = "string",
          description = "Returns a regular string from a base64 encoding.\n\n.. _digest-urandom:\n\n.",
          detail = "Decode a Base64-encoded string",
          type = "function"
        },
        base64_encode = {
          argsDisplay = "string[, opts]",
          description = "Returns base64 encoding from a regular string.\n\n    The possible options are:\n\n    * ``nopad`` -- result must not include '=' for padding at the end,\n    * ``nowrap`` -- result must not include line feed for splitting lines\n      after 72 characters,\n    * ``urlsafe`` -- result must not include '=' or line feed, and may contain\n      '-' or '_' instead of '+' or '/' for positions 62 and 63 in the index table.\n\n\n    Options may be ``true`` or ``false``, the default value is ``false``.\n\n    For example:\n\n    ```lua\n        digest.base64_encode(string_variable,{nopad=true})\n```\n\n.. _digest-base64_decode:\n\n.",
          detail = "Encode a string to Base64",
          type = "function"
        },
        crc32 = {
          argsDisplay = "string",
          description = "Returns 32-bit checksum made with CRC32.\n\n    The ``crc32`` and ``crc32_update`` functions use the `Cyclic Redundancy Check`_\n    polynomial value: ``0x1EDC6F41`` / ``4812730177``.\n    (Other settings are: input = reflected, output = reflected, initial value = 0xFFFFFFFF, final xor value = 0x0.)\n    If it is necessary to be\n    compatible with other checksum functions in other programming languages,\n    ensure that the other functions use the same polynomial value.\n\n    For example, in Python, install the ``crcmod`` package and say:\n\n    ```python\n        >>> import crcmod\n        >>> fun = crcmod.mkCrcFun('4812730177')\n        >>> fun('string')\n        3304160206L\n```\n\n    In Perl, install the ``Digest::CRC`` module and run the following code:\n\n    ```python\n      use Digest::CRC;\n      $d = Digest::CRC->new(width => 32, poly => 0x1EDC6F41, init => 0xFFFFFFFF, refin => 1, refout => 1);\n      $d->add('string');\n      print $d->digest;\n```\n\n    (the expected output is 3304160206).\n\n.. _digest-crc32_new:\n\n.",
          detail = "Get a 32-bit checksum made with CRC32",
          type = "function"
        },
        ["crc32.new"] = {
          detail = "Initiate incremental CRC32",
          type = "function"
        },
        digest = {
          description = "\n===============================================================================\n                                   Overview\n===============================================================================\n\nA \"digest\" is a value which is returned by a function (usually a\n`Cryptographic hash function`_), applied against a string. Tarantool's ``digest``\nmodule supports several types of cryptographic hash functions (AES_, MD4_,\nMD5_, SHA-1_, SHA-2_, PBKDF2_) as well as a checksum function (CRC32_), two\nfunctions for base64_, and two non-cryptographic hash functions (guava_, murmur_).\nSome of the digest functionality is also present in the `crypto`.\n\n===============================================================================\n                                    Index\n===============================================================================\n\nBelow is a list of all ``digest`` functions.\n\n.. container:: table\n\n    .. rst-class:: left-align-column-1\n    .. rst-class:: left-align-column-2\n\n    +--------------------------------------+---------------------------------+\n    | Name                                 | Use                             |\n    +======================================+=================================+\n    | `digest.aes256cbc.encrypt()     | Encrypt a string using AES      |\n    |`                        |                                 |\n    +--------------------------------------+---------------------------------+\n    | `digest.aes256cbc.decrypt()     | Decrypt a string using AES      |\n    |`                        |                                 |\n    +--------------------------------------+---------------------------------+\n    | `digest.md4()                   | Get a digest made with MD4      |\n    |`                        |                                 |\n    +--------------------------------------+---------------------------------+\n    | `digest.md4_hex()               | Get a hexadecimal digest made   |\n    |`                    | with MD4                        |\n    +--------------------------------------+---------------------------------+\n    | `digest.md5()                   | Get a digest made with MD5      |\n    |`                        |                                 |\n    +--------------------------------------+---------------------------------+\n    | `digest.md5_hex()               | Get a hexadecimal digest made   |\n    |`                    | with MD5                        |\n    +--------------------------------------+---------------------------------+\n    | `digest.pbkdf2()                | Get a digest made with PBKDF2   |\n    |`                     |                                 |\n    +--------------------------------------+---------------------------------+\n    | `digest.sha1()                  | Get a digest made with SHA-1    |\n    |`                       |                                 |\n    +--------------------------------------+---------------------------------+\n    | `digest.sha1_hex()              | Get a hexadecimal digest made   |\n    |`                   | with SHA-1                      |\n    +--------------------------------------+---------------------------------+\n    | `digest.sha224()                | Get a 224-bit digest made with  |\n    |`                     | SHA-2                           |\n    +--------------------------------------+---------------------------------+\n    | `digest.sha224_hex()            | Get a 56-byte hexadecimal       |\n    |`                 | digest made with SHA-2          |\n    +--------------------------------------+---------------------------------+\n    | `digest.sha256()                | Get a 256-bit digest made with  |\n    |`                     | SHA-2                           |\n    +--------------------------------------+---------------------------------+\n    | `digest.sha256_hex()            | Get a 64-byte hexadecimal       |\n    |`                 | digest made with SHA-2          |\n    +--------------------------------------+---------------------------------+\n    | `digest.sha384()                | Get a 384-bit digest made with  |\n    |`                     | SHA-2                           |\n    +--------------------------------------+---------------------------------+\n    | `digest.sha384_hex()            | Get a 96-byte hexadecimal       |\n    |`                 | digest made with SHA-2          |\n    +--------------------------------------+---------------------------------+\n    | `digest.sha512()                | Get a 512-bit digest made with  |\n    |`                     | SHA-2                           |\n    +--------------------------------------+---------------------------------+\n    | `digest.sha512_hex()            | Get a 128-byte hexadecimal      |\n    |`                 | digest made with SHA-2          |\n    +--------------------------------------+---------------------------------+\n    | `digest.base64_encode()         | Encode a string to Base64       |\n    |`              |                                 |\n    +--------------------------------------+---------------------------------+\n    | `digest.base64_decode()         | Decode a Base64-encoded string  |\n    |`              |                                 |\n    +--------------------------------------+---------------------------------+\n    | `digest.urandom()               | Get an array of random bytes    |\n    |`                    |                                 |\n    +--------------------------------------+---------------------------------+\n    | `digest.crc32()                 | Get a 32-bit checksum made with |\n    |`                      | CRC32                           |\n    +--------------------------------------+---------------------------------+\n    | `digest.crc32.new()             | Initiate incremental CRC32      |\n    |`                  |                                 |\n    +--------------------------------------+---------------------------------+\n    | `digest.guava()                 | Get a number made with a        |\n    |`                      | consistent hash                 |\n    +--------------------------------------+---------------------------------+\n    | `digest.murmur()                | Get a digest made with          |\n    |`                     | MurmurHash                      |\n    +--------------------------------------+---------------------------------+\n    | `digest.murmur.new()            | Initiate incremental MurmurHash |\n    |`                 |                                 |\n    +--------------------------------------+---------------------------------+\n\n.. _digest-aes:\n\n",
          type = "module"
        },
        ["digest.aes256cbc.encrypt"] = {
          argsDisplay = "string, key, iv",
          description = "Returns 256-bit binary string = digest made with AES.\n\n.. _digest-md4:\n\n.",
          type = "function"
        },
        ["digest.crc32.new"] = {
          argsDisplay = "",
          description = "Initiates incremental crc32.\n    See `incremental methods` notes.\n\n.. _digest-guava:\n\n.",
          type = "function"
        },
        ["digest.murmur.new"] = {
          argsDisplay = "opts",
          description = "Initiates incremental MurmurHash.\n    See `incremental methods` notes.\n    For example:\n\n    ```lua\n        murmur.new({seed=0})\n```\n\n.. _digest-incremental_digests:\n\n~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~\nIncremental methods in the ``digest`` module\n~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~\n\nSuppose that a digest is done for a string 'A', then a new part 'B' is appended\nto the string, then a new digest is required. The new digest could be recomputed\nfor the whole string 'AB', but it is faster to take what was computed before for\n'A' and apply changes based on the new part 'B'. This is called multi-step or\n\"incremental\" digesting, which Tarantool supports with crc32 and with murmur...\n\n```lua\n      digest = require('digest')\n```\n\n      -- print crc32 of 'AB', with one step, then incrementally\n      print(digest.crc32('AB'))\n      c = digest.crc32.new()\n      c:update('A')\n      c:update('B')\n      print(c:result())\n\n      -- print murmur hash of 'AB', with one step, then incrementally\n      print(digest.murmur('AB'))\n      m = digest.murmur.new()\n      m:update('A')\n      m:update('B')\n      print(m:result())\n\n~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~\nExample\n~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~\n\nIn the following example, the user creates two functions, ``password_insert()``\nwhich inserts a SHA-1_ digest of the word \"**^S^e^c^ret Wordpass**\" into a tuple\nset, and ``password_check()`` which requires input of a password.\n\n```lua\n    tarantool> digest = require('digest')\n    ---\n    ...\n    tarantool> function password_insert()\n             >   box.space.tester:insert{1234, digest.sha1('^S^e^c^ret Wordpass')}\n             >   return 'OK'\n             > end\n    ---\n    ...\n    tarantool> function password_check(password)\n             >   local t = box.space.tester:select{12345}\n             >   if digest.sha1(password) == t[2] then\n             >     return 'Password is valid'\n             >   else\n             >     return 'Password is not valid'\n             >   end\n             > end\n    ---\n    ...\n    tarantool> password_insert()\n    ---\n    - 'OK'\n    ...\n```\n\nIf a later user calls the ``password_check()`` function and enters the wrong\npassword, the result is an error.\n\n```lua\n    tarantool> password_check('Secret Password')\n    ---\n    - 'Password is not valid'\n    ...\n```\n\n.. _AES: https://en.wikipedia.org/wiki/Advanced_Encryption_Standard\n.. _SHA-1: https://en.wikipedia.org/wiki/Sha-1\n.. _SHA-2: https://en.wikipedia.org/wiki/Sha-2\n.. _MD4: https://en.wikipedia.org/wiki/Md4\n.. _MD5: https://en.wikipedia.org/wiki/Md5\n.. _CRC32: https://en.wikipedia.org/wiki/Cyclic_redundancy_check\n.. _base64: https://en.wikipedia.org/wiki/Base64\n.. _Cryptographic hash function: https://en.wikipedia.org/wiki/Cryptographic_hash_function\n.. _Consistent Hashing: https://en.wikipedia.org/wiki/Consistent_hashing\n.. _Cyclic Redundancy Check: https://en.wikipedia.org/wiki/Cyclic_redundancy_check\n.. _guava: https://code.google.com/p/guava-libraries/wiki/HashingExplained\n.. _Murmur: https://en.wikipedia.org/wiki/MurmurHash\n.. _PBKDF2: https://en.wikipedia.org/wiki/PBKDF2",
          type = "function"
        },
        guava = {
          argsDisplay = "state, bucket",
          description = "Returns a number made with consistent hash.\n\n    The guava function uses the `Consistent Hashing`_ algorithm of the Google\n    guava library. The first parameter should be a hash code; the second\n    parameter should be the number of buckets; the returned value will be an\n    integer between 0 and the number of buckets. For example,\n\n    ```lua\n        tarantool> digest.guava(10863919174838991, 11)\n        ---\n        - 8\n        ...\n```\n\n.. _digest-murmur:\n\n.",
          detail = "Get a number made with a consistent hash",
          type = "function"
        },
        md4 = {
          argsDisplay = "string",
          description = "Returns 128-bit binary string = digest made with MD4.\n\n.. _digest-md4_hex:\n\n.",
          detail = "Get a digest made with MD4",
          type = "function"
        },
        md4_hex = {
          argsDisplay = "string",
          description = "Returns 32-byte string = hexadecimal of a digest calculated with md4.\n\n.. _digest-md5:\n\n.",
          detail = "Get a hexadecimal digest made with MD4",
          type = "function"
        },
        md5 = {
          argsDisplay = "string",
          description = "Returns 128-bit binary string = digest made with MD5.\n\n.. _digest-md5_hex:\n\n.",
          detail = "Get a digest made with MD5",
          type = "function"
        },
        md5_hex = {
          argsDisplay = "string",
          description = "Returns 32-byte string = hexadecimal of a digest calculated with md5.\n\n.. _digest-pbkdf2:\n\n.",
          detail = "Get a hexadecimal digest made with MD5",
          type = "function"
        },
        murmur = {
          argsDisplay = "string",
          description = "Returns 32-bit binary string = digest made with MurmurHash.\n\n.. _digest-murmur_new:\n\n.",
          detail = "Get a digest made with MurmurHash",
          type = "function"
        },
        ["murmur.new"] = {
          detail = "Initiate incremental MurmurHash",
          type = "function"
        },
        pbkdf2 = {
          argsDisplay = "string, salt [,iterations [,digest-length]]",
          description = "Returns binary string = digest made with PBKDF2. |br|\n    For effective encryption the ``iterations`` value should be\n    at least several thousand. The ``digest-length`` value\n    determines the length of the resulting binary string.\n\n.. _digest-sha1:\n\n.",
          detail = "Get a digest made with PBKDF2",
          type = "function"
        },
        sha1 = {
          argsDisplay = "string",
          description = "Returns 160-bit binary string = digest made with SHA-1.\n\n.. _digest-sha1_hex:\n\n.",
          detail = "Get a digest made with SHA-1",
          type = "function"
        },
        sha1_hex = {
          argsDisplay = "string",
          description = "Returns 40-byte string = hexadecimal of a digest calculated with sha1.\n\n.. _digest-sha224:\n\n.",
          detail = "Get a hexadecimal digest made with SHA-1",
          type = "function"
        },
        sha224 = {
          argsDisplay = "string",
          description = "Returns 224-bit binary string = digest made with SHA-2.\n\n.. _digest-sha224_hex:\n\n.",
          detail = "Get a 224-bit digest made with SHA-2",
          type = "function"
        },
        sha224_hex = {
          argsDisplay = "string",
          description = "Returns 56-byte string = hexadecimal of a digest calculated with sha224.\n\n.. _digest-sha256:\n\n.",
          detail = "Get a 56-byte hexadecimal digest made with SHA-2",
          type = "function"
        },
        sha256 = {
          argsDisplay = "string",
          description = "Returns 256-bit binary string =  digest made with SHA-2.\n\n.. _digest-sha256_hex:\n\n.",
          detail = "Get a 256-bit digest made with SHA-2",
          type = "function"
        },
        sha256_hex = {
          argsDisplay = "string",
          description = "Returns 64-byte string = hexadecimal of a digest calculated with sha256.\n\n.. _digest-sha384:\n\n.",
          detail = "Get a 64-byte hexadecimal digest made with SHA-2",
          type = "function"
        },
        sha384 = {
          argsDisplay = "string",
          description = "Returns 384-bit binary string =  digest made with SHA-2.\n\n.. _digest-sha384_hex:\n\n.",
          detail = "Get a 384-bit digest made with SHA-2",
          type = "function"
        },
        sha384_hex = {
          argsDisplay = "string",
          description = "Returns 96-byte string = hexadecimal of a digest calculated with sha384.\n\n.. _digest-sha512:\n\n.",
          detail = "Get a 96-byte hexadecimal digest made with SHA-2",
          type = "function"
        },
        sha512 = {
          argsDisplay = "string",
          description = "Returns 512-bit binary tring = digest made with SHA-2.\n\n.. _digest-sha512_hex:\n\n.",
          detail = "Get a 512-bit digest made with SHA-2",
          type = "function"
        },
        sha512_hex = {
          argsDisplay = "string",
          description = "Returns 128-byte string = hexadecimal of a digest calculated with sha512.\n\n.. _digest-base64_encode:\n\n.",
          detail = "Get a 128-byte hexadecimal digest made with SHA-2",
          type = "function"
        },
        urandom = {
          argsDisplay = "integer",
          description = "Returns array of random bytes with length = integer.\n\n.. _digest-crc32:\n\n.",
          detail = "Get an array of random bytes",
          type = "function"
        }
      },
      type = "table"
    }
  },
  type = "table"
}