return {
  fields = {
    json = {
      fields = {
        NULL = {
          detail = "",
          type = "function"
        },
        cfg = {
          argsDisplay = "list of parameter assignments",
          description = "Set values affecting behavior of `json.encode`\n    and `json.decode`.\n\n    The values are all either integers or boolean ``true``/``false`` values.\n\n    * ``cfg.encode_deep_as_nil`` (default is false) -- see `below`\n    * ``cfg.encode_invalid_as_nil`` (default is false) -- use ``null`` for all\n      unrecognizable types\n    * ``cfg.encode_invalid_numbers`` (default is true) -- allow nan and inf\n    * ``cfg.encode_load_metatables`` (default is true) -- load metatables\n    * ``cfg.encode_max_depth`` (default is 32) -- maximum nesting depth in a structure\n    * ``cfg.encode_number_precision`` (default is 14) -- maximum post-decimal digits\n    * ``cfg.encode_sparse_convert`` (default is true) -- handle excessively sparse arrays as maps\n    * ``cfg.encode_sparse_ratio`` (default is 2) -- how sparse an array can be\n    * ``cfg.encode_sparse_safe`` (default is 10) -- how much can safely be sparse\n    * ``cfg.encode_use_tostring`` (default is false) -- use ``tostring`` for\n      unrecognizable types\n    * ``cfg.decode_invalid_numbers`` (default is true) -- allow nan and inf\n    * ``cfg.decode_max_depth`` (default is 32) -- maximum nesting depth in a structure\n    * ``cfg.decode_save_metatables`` (default is true) -- like ``encode_load_metatables``\n\n    For example, the following code will encode 0/0 as nan (\"not a number\")\n    and 1/0 as inf (\"infinity\"), rather than returning nil or an error message:\n\n    ```lua\n        json = require('json')\n        json.cfg{encode_invalid_numbers = true}\n        x = 0/0\n        y = 1/0\n        json.encode({1, x, y, 2})\n```\n\n    The result of the ``json.encode()`` request will look like this:\n\n    ```lua\n        tarantool> json.encode({1, x, y, 2})\n        ---\n        - '[1,nan,inf,2]\n        ...\n```\n\n    To achieve the same effect for only one call to ``json.encode()`` without\n    changing the configuration persistently, one could say\n    ``json.encode({1, x, y, 2}, {encode_invalid_numbers = true})``.\n\n    The same configuration settings exist for json, for `MsgPack\n   `, and for `YAML`.\n\n.. _json-module.cfg_encode_deep_as_nil:\n\n.. NOTE::\n\n    **Behavior change:** Before Tarantool version 1.10.4,\n    if a nested structure was deeper than ``cfg.encode_max_depth``,\n    the deeper levels were cropped (encoded as nil).\n\n    Now, the result is an error suggesting that ``cfg.encode_max_depth``\n    is not deep enough. To return to the old behavior, say\n    ``cfg.encode_deep_as_nil = true``.\n\n    This option is ignored for ``YAML``.\n\n.. _Lua-CJSON module by Mark Pulford: http://www.kyne.com.au/~mark/software/lua-cjson.php\n.. _the official documentation: http://www.kyne.com.au/~mark/software/lua-cjson-manual.html",
          detail = "Set global flags",
          type = "function"
        },
        decode = {
          argsDisplay = "string [,configuration]",
          description = "Convert a JSON string to a Lua object.",
          detail = "Convert a JSON string to a Lua object",
          type = "function"
        },
        encode = {
          argsDisplay = "lua-value [, configuration]",
          description = "Convert a Lua object to a JSON string.\n\n    :param lua_value: either a scalar value or a Lua table value.\n    :param configuration: see `json.cfg`\n    :return: the original value reformatted as a JSON string.\n    :rtype: string\n\n    **Example:**\n\n    ```lua\n        tarantool> json=require('json')\n        ---\n        ...\n        tarantool> json.encode(123)\n        ---\n        - '123'\n        ...\n        tarantool> json.encode({123})\n        ---\n        - '[123]'\n        ...\n        tarantool> json.encode({123, 234, 345})\n        ---\n        - '[123,234,345]'\n        ...\n        tarantool> json.encode({abc = 234, cde = 345})\n        ---\n        - '{\"cde\":345,\"abc\":234}'\n        ...\n        tarantool> json.encode({hello = {'world'}})\n        ---\n        - '{\"hello\":[\"world\"]}'\n        ...\n```\n\n.. _json-decode:\n\n.",
          detail = "Convert a Lua object to a JSON string",
          type = "function"
        },
        json = {
          description = "\n.. _json-encode:\n\n",
          type = "module"
        }
      },
      type = "table"
    }
  },
  type = "table"
}