return {
  fields = {
    log = {
      fields = {
        debug = {
          detail = "",
          type = "function"
        },
        error = {
          argsDisplay = "message",
          description = "Output a user-generated message to the `log file`,\n    given log_level_function_name = ``error`` or ``warn`` or ``info`` or\n    ``verbose`` or ``debug``.\n\n    As explained in the description of the configuration setting for\n    `log_level`, there are seven levels of detail:\n\n    * 1 – ``SYSERROR``\n    * 2 – ``ERROR`` -- this corresponds to ``log.error(...)``\n    * 3 – ``CRITICAL``\n    * 4 – ``WARNING``  -- this corresponds to ``log.warn(...)``\n    * 5 – ``INFO`` -- this corresponds to ``log.info(...)``\n    * 6 – ``VERBOSE``  -- this corresponds to ``log.verbose(...)``\n    * 7 – ``DEBUG`` -- this corresponds to ``log.debug(...)``\n\n    For example, if ``box.cfg.log_level`` is currently 5 (the default value),\n    then ``log.error(...)``, ``log.warn(...)`` and ``log.info(...)`` messages\n    will go to the log file. However, ``log.verbose(...)`` and\n    ``log.debug(...)`` messages will not go to the log file, because they\n    correspond to higher levels of detail.\n\n    :param any message:    Usually a string.\n\n                           Messages may contain C-style format specifiers %d or\n                           %s, so :samp:`log.error('...%d...%s', {x}, {y})`\n                           will work if ``x`` is a number and ``y`` is a string.\n\n                           Less commonly, messages may be other scalar data types,\n                           or even tables. So :code:`log.error({'x',18.7,true})`\n                           will work.",
          detail = " Write a user-generated message to a log file",
          type = "function"
        },
        info = {
          detail = "Write a user-generated message to a log file",
          type = "function"
        },
        log = {
          description = "\n===============================================================================\n                                   Overview\n===============================================================================\n\nThe Tarantool server puts all diagnostic messages in a log file specified by\nthe `log` configuration parameter. Diagnostic\nmessages may be either system-generated by the server's internal code, or\nuser-generated with the :samp:`log.{log_level_function_name}` function.\n\nAs explained in the description of `log_format` \nconfiguration setting, there are two possible formats for log entries:\n\n* 'plain' (the default), or\n* 'json' (with more detail and with JSON labels).\n\nHere is what a log entry looks like after ``box.cfg{log_format='plain'}``:\n\n```text\n    2017-10-16 11:36:01.508 [18081] main/101/interactive I> set 'log_format' configuration option to \"plain\"\n```\n\nHere is what a log entry looks like after ``box.cfg{log_format='json'}``:\n\n```text\n    {\"time\": \"2017-10-16T11:36:17.996-0600\",\n    \"level\": \"INFO\",\n    \"message\": \"set 'log_format' configuration option to \\\"json\\\"\",\n    \"pid\": 18081,|\n    \"cord_name\": \"main\",\n    \"fiber_id\": 101,\n    \"fiber_name\": \"interactive\",\n    \"file\": \"builtin\\/box\\/load_cfg.lua\",\n    \"line\": 317}\n```\n\n===============================================================================\n                                    Index\n===============================================================================\n\nBelow is a list of all ``log`` functions.\n\n.. container:: table\n\n    .. rst-class:: left-align-column-1\n    .. rst-class:: left-align-column-2\n\n    +--------------------------------------+---------------------------------+\n    | Name                                 | Use                             |\n    +======================================+=================================+\n    | `log.error()                    |                                 |\n    |` |br|               |                                 |\n    | `log.warn()                     |                                 |\n    |` |br|               |                                 |\n    | `log.info()                     | Write a user-generated message  |\n    |` |br|               | to a log file                   |\n    | `log.verbose()                  |                                 |\n    |` |br|               |                                 |\n    | `log.debug()                    |                                 |\n    |`                    |                                 |\n    +--------------------------------------+---------------------------------+\n    | `log.logger_pid()               | Get the PID of a logger         |\n    |`                    |                                 |\n    +--------------------------------------+---------------------------------+\n    | `log.rotate()                   | Rotate a log file               |\n    |`                        |                                 |\n    +--------------------------------------+---------------------------------+\n\n.. _log-ug_message:\n\n",
          type = "module"
        },
        logger_pid = {
          argsDisplay = "",
          description = ":return: PID of a logger\n\n.. _log-rotate:\n\n.",
          detail = "Get the PID of a logger",
          type = "function"
        },
        rotate = {
          argsDisplay = "",
          description = "Rotate the log.",
          detail = "Rotate a log file",
          type = "function"
        },
        verbose = {
          detail = "",
          type = "function"
        },
        warn = {
          detail = " Write a user-generated message to a log file",
          type = "function"
        }
      },
      type = "table"
    }
  },
  type = "table"
}