return {
  fields = {
    msgpack = {
      fields = {
        NULL = {
          detail = "",
          type = "function"
        },
        cfg = {
          argsDisplay = "table",
          description = "Some MsgPack configuration settings can be changed, in the\n    same way that they can be changed for json.\n    See `Module JSON` for a list of some configuration settings.\n    (The same configuration settings exist for json, for MsgPack, and for  `YAML`.)\n\n    For example, if ``msgpack.cfg.encode_invalid_numbers = true`` (the default),\n    then nan and inf are legal values. If that is not desirable, then\n    ensure that ``msgpack.encode()`` will not accept them, by saying\n    ``msgpack.cfg{encode_invalid_numbers = false}``, thus:\n\n    ```none\n        tarantool> msgpack = require('msgpack'); msgpack.cfg{encode_invalid_numbers = true}\n        ---\n        ...\n        tarantool> msgpack.decode(msgpack.encode{1, 0 / 0, 1 / 0, false})\n        ---\n        - [1, -nan, inf, false]\n        - 22\n        ...\n        tarantool> msgpack.cfg{encode_invalid_numbers = false}\n       ---\n       ...\n        tarantool> msgpack.decode(msgpack.encode{1, 0 / 0, 1 / 0, false})\n        ---\n        - error: ... number must not be NaN or Inf'\n       ...\n```\n\n\n.. _MsgPack: http://msgpack.org/\n.. _Specification: http://github.com/msgpack/msgpack/blob/master/spec.md",
          detail = "Change configuration",
          type = "function"
        },
        decode = {
          argsDisplay = "msgpack_string [, start_position]",
          description = "Convert a MsgPack string to a Lua object.\n\n    :param string msgpack_string: a string formatted as MsgPack.\n    :param integer start_position: where to start, minimum = 1,\n                                   maximum = string length, default = 1.\n\n    :return:\n\n      * (if ``msgpack_string`` is in valid MsgPack format) the original contents\n        of ``msgpack_string``, formatted as a Lua table,\n        (otherwise) a scalar value, such as a string or a number;\n      * \"next_start_position\". If ``decode`` stops after parsing as far as\n        byte N in ``msgpack_string``, then \"next_start_position\" will equal N + 1,\n        and ``decode(msgpack_string, next_start_position)``\n        will continue parsing from where the previous ``decode`` stopped, plus 1.\n        Normally ``decode`` parses all of ``msgpack_string``, so\n        \"next_start_position\" will equal ``string.len(msgpack_string)`` + 1.",
          detail = "Convert a MsgPack string to a Lua object",
          type = "function"
        },
        decode_unchecked = {
          argsDisplay = "string",
          description = "Convert a MsgPack string to a Lua object.\n    Because checking is skipped, ``decode_unchecked()``\n    can operate with string pointers to\n    buffers which ``decode()`` cannot handle.\n    For an example see the `buffer` module.\n\n    :param string: a string formatted as MsgPack.\n\n    :return:\n\n      * the original contents formatted as a Lua table;\n      * the number of bytes that were decoded.",
          detail = "Convert a MsgPack string to a Lua object",
          type = "function"
        },
        encode = {
          argsDisplay = "lua_value",
          description = "Convert a Lua object to a MsgPack string.\n\n    :param lua_value: either a scalar value or a Lua table value.\n    :return: the original value reformatted as a MsgPack string.\n    :rtype: string\n\n.. _msgpack-decode:\n\n.",
          detail = "Convert a Lua object to an MsgPack string",
          type = "function"
        },
        msgpack = {
          description = "\n.. _msgpack-encode:\n\n",
          type = "module"
        }
      },
      type = "table"
    }
  },
  type = "table"
}