return {
  fields = {
    net_box = {
      fields = {
        conn = {
          detail = "Set a timeout",
          type = "function"
        },
        ["conn.space.space"] = {
          detail = "Delete a tuple",
          type = "function"
        },
        connect = {
          argsDisplay = "URI [, {option[s]}]",
          description = ".. _net_box-new:\n\n.",
          detail = " Create a connection",
          type = "function"
        },
        net_box = {
          description = "\n.. _net_box-connect:\n\n",
          type = "module"
        },
        ["net_box.on_connect"] = {
          argsDisplay = "[trigger-function[, old-trigger-function]]){option[s]}]",
          description = "Define a trigger for execution when a new connection is created due to an\n    event such as ``net_box.connect``. The trigger function will be the first thing\n    executed after a new connection is created. If the trigger execution fails\n    and raises an error, the error is sent to the client and the connection is closed.",
          type = "function"
        },
        ["net_box.on_disconnect"] = {
          argsDisplay = "[trigger-function[, old-trigger-function]]){option[s]}]",
          description = "Define a trigger for execution after a connection is closed. If the trigger\n    function causes an error, the error is logged but otherwise is ignored.\n    Execution stops after a connection is explicitly closed, or once the Lua\n    garbage collector removes it.",
          type = "function"
        },
        ["net_box.on_schema_reload"] = {
          argsDisplay = "[trigger-function[, old-trigger-function]]){option[s]}]",
          description = "Define a trigger executed when some operation has been performed on the remote\n    server after schema has been updated. So, if a server request fails due to a schema\n    version mismatch error, schema reload is triggered.",
          type = "function"
        },
        new = {
          argsDisplay = "URI [, {option[s]}]",
          description = ".. NOTE::\n\n       The names ``connect()`` and ``new()`` are synonyms: ``connect()`` is\n       preferred; ``new()`` is retained for backward compatibility.\n\n    Create a new connection. The connection is established on demand, at the\n    time of the first request. It can be re-established automatically after a\n    disconnect (see ``reconnect_after`` option below).\n    The returned ``conn`` object supports methods for making remote requests,\n    such as select, update or delete.\n\n    For a local Tarantool server, there is a pre-created always-established\n    connection object named :samp:`{net_box}.self`. Its purpose is to make\n    polymorphic use of the ``net_box`` API easier. Therefore\n    :samp:`conn = {net_box}.connect('localhost:3301')`\n    can be replaced by :samp:`conn = {net_box}.self`. However, there is an\n    important difference between the embedded connection and a remote one.\n    With the embedded connection, requests which do not modify data do not yield.\n    When using a remote connection, due to\n    `the implicit rules`\n    any request can yield, and database state may have changed by the time it\n    regains control.\n\n    Possible options:\n\n    * `user/password`: you have two ways to connect to a remote host:\n      using `URI` or using the options `user` and `password`. For\n      example, instead of ``connect('username:userpassword@localhost:33301')`` you\n      can write ``connect('localhost:33301', {user = 'username', password='userpassword'})``.\n\n    * `wait_connected`: by default, connection creation is blocked until the connection is established,\n      but passing ``wait_connected=false`` makes it return immediately. Also, passing a timeout\n      makes it wait before returning (e.g. ``wait_connected=1.5`` makes it wait at most 1.5 seconds).\n\n      .. NOTE::\n\n         In the presence of ``reconnect_after``, ``wait_connected`` ignores transient failures.\n         The wait completes once the connection is established or is closed explicitly.\n\n    * `reconnect_after`: a ``net.box`` instance automatically reconnects\n      any time the connection is broken or if a connection attempt fails.\n      This makes transient network failures become transparent to the application.\n      Reconnect happens automatically in the background, so queries/requests that\n      suffered due to connectivity loss are transparently retried.\n      The number of retries is unlimited, connection attempts are done over the\n      specified timeout (e.g. ``reconnect_after=5`` for 5 secs).\n      Once a connection is explicitly closed, or once the Lua garbage collector\n      removes it, reconnects stop.\n\n    * `call_16`: [since 1.7.2] by default, ``net.box`` connections comply with a new\n      binary protocol command for CALL, which is not backward compatible with previous versions.\n      The new CALL no longer restricts a function to returning an array of tuples\n      and allows returning an arbitrary MsgPack/JSON result, including scalars, nil and void (nothing).\n      The old CALL is left intact for backward compatibility.\n      It will be removed in the next major release.\n      All programming language drivers will be gradually changed to use the new CALL.\n      To connect to a Tarantool instance that uses the old CALL, specify ``call_16=true``.\n\n    * `console`: depending on the option's value, the connection supports different methods\n      (as if instances of different classes were returned). With ``console = true``, you can use\n      ``conn`` methods ``close()``, ``is_connected()``, ``wait_state()``, ``eval()`` (in this case, both\n      binary and Lua console network protocols are supported). With ``console = false`` (default), you can\n      also use ``conn`` database methods (in this case, only the binary protocol is supported).\n      Deprecation notice: ``console = true`` is deprecated, users should use\n      `console.connect()` instead.\n\n    * `connect_timeout`: number of seconds to wait before returning \"error: Connection timed out\".\n\n    :param string URI: the `URI` of the target for the connection\n    :param options: possible options are `user`, `password`, `wait_connected`,\n                    `reconnect_after`, `call_16`, `console` and `connect_timeout`\n    :return: conn object\n    :rtype:  userdata\n\n    **Examples:**\n\n    ```lua\n        conn = net_box.connect('localhost:3301')\n        conn = net_box.connect('127.0.0.1:3302', {wait_connected = false})\n        conn = net_box.connect('127.0.0.1:3303', {reconnect_after = 5, call_16 = true})\n```\n\n.. class:: conn\n\n    .. _conn-ping:\n\n    .. method:: ping([options])\n\n        Execute a PING command.\n\n        :param table options: the supported option is :samp:`timeout={seconds}`\n        :return: true on success, false on error\n        :rtype:  boolean\n\n        **Example:**\n\n        ```lua\n            net_box.self:ping({timeout = 0.5})\n```\n\n    .. _conn-wait_connected:\n\n    .. method:: wait_connected([timeout])\n\n        Wait for connection to be active or closed.\n\n        :param number timeout: in seconds\n        :return: true when connected, false on failure.\n        :rtype:  boolean\n\n        **Example:**\n\n        ```lua\n            net_box.self:wait_connected()\n```\n\n    .. _conn-is_connected:\n\n    .. method:: is_connected()\n\n        Show whether connection is active or closed.\n\n        :return: true if connected, false on failure.\n        :rtype:  boolean\n\n        **Example:**\n\n        ```lua\n            net_box.self:is_connected()\n```\n\n    .. _conn-wait_state:\n\n    .. method:: wait_state(state[s][, timeout])\n\n        [since 1.7.2] Wait for a target state.\n\n        :param string states: target states\n        :param number timeout: in seconds\n        :return: true when a target state is reached, false on timeout or connection closure\n        :rtype:  boolean\n\n        **Examples:**\n\n        ```lua\n            -- wait infinitely for 'active' state:\n            conn:wait_state('active')\n```\n\n            -- wait for 1.5 secs at most:\n            conn:wait_state('active', 1.5)\n\n            -- wait infinitely for either `active` or `fetch_schema` state:\n            conn:wait_state({active=true, fetch_schema=true})\n\n    .. _conn-close:\n\n    .. method:: close()\n\n        Close a connection.\n\n        Connection objects are destroyed by the Lua garbage collector, just like any other objects in Lua, so\n        an explicit destruction is not mandatory. However, since close() is a system\n        call, it is good programming practice to close a connection explicitly when it\n        is no longer needed, to avoid lengthy stalls of the garbage collector.\n\n        **Example:**\n\n        ```lua\n            conn:close()\n```\n\n    .. _conn-select:\n\n    .. method:: conn.space.<space-name>:select({field-value, ...} [, {options}])\n\n        :samp:`conn.space.{space-name}:select`:code:`({...})` is the remote-call equivalent\n        of the local call :samp:`box.space.{space-name}:select`:code:`{...}`.\n\n        **Example:**\n\n        ```lua\n            conn.space.testspace:select({1,'B'}, {timeout=1})\n```\n\n        .. NOTE::\n\n            Due to `the implicit yield rules`\n            a local :samp:`box.space.{space-name}:select`:code:`{...}` does\n            not yield, but a remote :samp:`conn.space.{space-name}:select`:code:`{...}`\n            call does yield, so global variables or database tuples data may\n            change when a remote :samp:`conn.space.{space-name}:select`:code:`{...}`\n            occurs.\n\n    .. _conn-get:\n\n    .. method:: conn.space.<space-name>:get({field-value, ...} [, {options}])\n\n        :samp:`conn.space.{space-name}:get(...)` is the remote-call equivalent\n        of the local call :samp:`box.space.{space-name}:get(...)`.\n\n        **Example:**\n\n        ```lua\n            conn.space.testspace:get({1})\n```\n\n    .. _conn-insert:\n\n    .. method:: conn.space.<space-name>:insert({field-value, ...} [, {options}])\n\n        :samp:`conn.space.{space-name}:insert(...)` is the remote-call equivalent\n        of the local call :samp:`box.space.{space-name}:insert(...)`.\n\n        **Example:**\n\n        ```lua\n            conn.space.testspace:insert({2,3,4,5}, {timeout=1.1})\n```\n\n    .. _conn-replace:\n\n    .. method:: conn.space.<space-name>:replace({field-value, ...} [, {options}])\n\n        :samp:`conn.space.{space-name}:replace(...)` is the remote-call equivalent\n        of the local call :samp:`box.space.{space-name}:replace(...)`.\n\n        **Example:**\n\n        ```lua\n            conn.space.testspace:replace({5,6,7,8})\n```\n\n    .. _conn-update:\n\n    .. method:: conn.space.<space-name>:update({field-value, ...} [, {options}])\n\n        :samp:`conn.space.{space-name}:update(...)` is the remote-call equivalent\n        of the local call :samp:`box.space.{space-name}:update(...)`.\n\n        **Example:**\n\n        ```lua\n            conn.space.Q:update({1},{{'=',2,5}}, {timeout=0})\n```\n\n    .. _conn-upsert:\n\n    .. method:: conn.space.<space-name>:upsert({field-value, ...} [, {options}])\n\n        :samp:`conn.space.{space-name}:upsert(...)` is the remote-call equivalent\n        of the local call :samp:`box.space.{space-name}:upsert(...)`.\n\n    .. _conn-delete:\n\n    .. method:: conn.space.<space-name>:delete({field-value, ...} [, {options}])\n\n        :samp:`conn.space.{space-name}:delete(...)` is the remote-call equivalent\n        of the local call :samp:`box.space.{space-name}:delete(...)`.\n\n    .. _net_box-eval:\n\n    .. method:: eval(Lua-string [, {arguments}, [ {options} ]])",
          detail = "",
          type = "function"
        },
        on_connect = {
          detail = "Define a connect trigger",
          type = "function"
        },
        on_disconnect = {
          detail = "Define a disconnect trigger",
          type = "function"
        },
        on_schema_reload = {
          detail = "Define a trigger when schema is modified",
          type = "function"
        }
      },
      type = "table"
    }
  },
  type = "table"
}