return {
  fields = {
    xlog = {
      fields = {
        xlog = {
          description = "\n.. _xlog-pairs:\n\n.. method:: pairs([file-name])\n\n    Open a file, and allow iterating over one file entry at a time.\n\n    :returns: iterator  which can be used in a for/end loop.\n    :rtype: `iterator <https://www.lua.org/pil/7.1.html>`_\n\n    Possible errors: File does not contain properly formatted snapshot or\n    write-ahead-log information.\n\n    **Example:**\n\n    This will read the first write-ahead-log (WAL) file that was created in the\n    `wal_dir` directory \n    in our `\"Getting started\" exercises`.\n\n    Each result from ``pairs()`` is formatted with MsgPack so its structure can\n    be specified with `__serialize`.\n\n    ```lua\n        xlog = require('xlog')\n        t = {}\n        for k, v in xlog.pairs('00000000000000000000.xlog') do\n          table.insert(t, setmetatable(v, { __serialize = \"map\"}))\n        end\n        return t\n```\n\n    The first lines of the result will look like:\n\n    .. code-block:: tarantoolsession\n\n        (...)\n        ---\n        - - {'BODY':   {'space_id': 272, 'index_base': 1, 'key': ['max_id'],\n                        'tuple': [['+', 2, 1]]},\n             'HEADER': {'type': 'UPDATE', 'timestamp': 1477846870.8541,\n                        'lsn': 1, 'server_id': 1}}\n          - {'BODY':   {'space_id': 280,\n                         'tuple': [512, 1, 'tester', 'memtx', 0, {}, []]},\n             'HEADER': {'type': 'INSERT', 'timestamp': 1477846870.8597,\n                        'lsn': 2, 'server_id': 1}}",
          type = "module"
        }
      },
      type = "table"
    }
  },
  type = "table"
}